# localSQL

`localSQL` 是一个简单的 SQLite 数据库操作助手类，旨在帮助用户在 Python 中快速管理 SQLite 数据库，包括创建表、插入记录、更新插入（Upsert）、查询和删除记录等常见操作。

## 安装:

你可以通过以下命令安装 `localSQL` 包：

--- 
```
pip install localSQL
```

--- 

## 使用方法

### 1. 导入并创建数据库对象

```python
from localSQL import SQLiteDB

# 创建数据库对象
db = SQLiteDB('example.db')
```


### 2. 创建表
```python
db.create_table('locations', {
    "id": "INTEGER PRIMARY KEY AUTOINCREMENT",
    "time": "TEXT NOT NULL",
    "region": "TEXT NOT NULL",
    "address": "TEXT NOT NULL",
    "name": "TEXT NOT NULL",
    "phone": "TEXT NOT NULL",
    "is_added": "BOOLEAN NOT NULL"
})
```
### 3. 插入记录
```python
db.insert_record('locations', {
    "time": "2024-12-07 11:00:00",
    "region": "河南洛阳A",
    "address": "洛阳市新安县老城河南88号",
    "name": "李四",
    "phone": "15037995595871",
    "is_added": False
})
```


### 4. 更新或插入记录（Upsert）
```python
db.upsert_record('locations', {
    "time": "2024-12-07 11:30:00",  # 更新时间
    "region": "河南洛阳A",
    "address": "洛阳市新安县老城河南88号",
    "name": "李四",
    "phone": "15037995595871",
    "is_added": True  # 更新状态为已添加
}, conditions=["phone"])  # 根据手机号判断是否存在记录
```
### 5. 删除记录
```python
使用 delete_record 方法删除符合条件的记录。例如：

python
复制代码
db.delete_record('locations', {"region": "河南洛阳A"})
```
### 6. 查询记录
```python
records = db.query_records('locations', {"region": "河南洛阳A"})
print("查询到的记录：")
for record in records:
    print(record)
```
### 7. 关闭数据库连接
```python
db.close()
```
---
许可证
该项目采用 MIT 许可证，详情请查看 LICENSE 文件。

### 5. **LICENSE 文件（可选）**

如果你选择使用 MIT 许可证，`LICENSE` 文件的内容可以是：

MIT License

Copyright (c) 2024 Your Name

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.